AttenuationOrder

Trait AttenuationOrder 

pub trait AttenuationOrder {
    // Required method
    fn attenuates(
        &self,
        current: &IndexedAuthorityMap,
        predecessor: &IndexedAuthorityMap,
    ) -> bool;
}
The profile-defined attenuation order used for non-expansion validation. A Verifier rejects a state whose order it cannot evaluate deterministically.

Required Methods

fn attenuates( &self, current: &IndexedAuthorityMap, predecessor: &IndexedAuthorityMap, ) -> bool

Returns true when current is equal to or more restrictive than predecessor.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors